/* While this template provides a good starting point for using Wear Compose, you can always
 * take a look at https://github.com/android/wear-os-samples/tree/main/ComposeStarter and
 * https://github.com/android/wear-os-samples/tree/main/ComposeAdvanced to find the most up to date
 * changes to the libraries and their usages.
 */

package io.ixlo.changes_wear.presentation

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.core.splashscreen.SplashScreen.Companion.installSplashScreen
import androidx.wear.compose.material.Button
import androidx.wear.compose.material.ButtonDefaults
import androidx.wear.compose.material.MaterialTheme
import androidx.wear.compose.material.Text
import androidx.wear.tooling.preview.devices.WearDevices
import io.ixlo.changes_wear.R
import io.ixlo.changes_wear.presentation.theme.Changes易Theme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        installSplashScreen()

        super.onCreate(savedInstanceState)

        setTheme(android.R.style.Theme_DeviceDefault)

        setContent {
            ChangesApp()
        }
    }
}

private fun genHex(): Hexagram {
    val lineMap = mapOf(1 to 6, 2 to 9, 3 to 9, 4 to 9, 5 to 7,
        6 to 7, 7 to 7, 8 to 7, 9 to 7, 10 to 8, 11 to 8,
        12 to 8, 13 to 8, 14 to 8, 15 to 8, 16 to 8
    )

    var hex = mutableListOf<Int>()

    for (i in 1..6) {
        hex.add(lineMap[(1..16).random()]!!)
    }

    return Hexagram(hex.toList())
}

@Composable
fun ChangesApp() {

    var hex by rememberSaveable {
        mutableStateOf("\n\n\n\n\n\n")
    }

    Changes易Theme {
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(MaterialTheme.colors.background),
            contentAlignment = Alignment.Center
        ) {
            //TimeText()
            //Greeting(greetingName = greetingName)
            Column(
                modifier = Modifier
                    //.padding(it)
                    .padding(12.dp)
                    .fillMaxSize(),
                verticalArrangement = Arrangement.Bottom,
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Text(
                    text = hex.toString(),
                    fontSize = 18.sp,
                    fontFamily = FontFamily.Monospace,
                    //fontWeight = FontWeight.Bold
                )
                Button(
                    onClick = { hex = genHex().toString() },
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = Color.Red
                )
                ) {
                    Text(
                        text = stringResource(R.string.divineButton),
                        fontSize = 24.sp,
                        color = Color.Black
                        //fontWeight = FontWeight.Bold
                    )
                }
            }
        }
    }
}

/*@Composable
fun Greeting(greetingName: String) {
    Text(
        modifier = Modifier.fillMaxWidth(),
        textAlign = TextAlign.Center,
        color = MaterialTheme.colors.primary,
        text = stringResource(R.string.hello_world, greetingName)
    )
}*/

@Preview(device = WearDevices.LARGE_ROUND, showSystemUi = true)
@Composable
fun DefaultPreview() {
    ChangesApp()
}